# Gemican

Gemican is a static gemini capsule generator, written in [Python](https://www.python.org/), and based on the static site generator [Pelican](https://github.com/getpelican/pelican).

* Write content in [Markdown](https://daringfireball.net/projects/markdown/) or directly in Gemtext using your editor of choice
* Includes a simple command line tool to (re)generate capsule files
* Easy to interface with version control systems and web hooks
* Completely static output is simple to host anywhere


## Features

Gemican’s feature highlights include:

* Chronological content (e.g., articles, blog posts) as well as static pages
* Site themes (created using Jinja2_ templates)
* Publication of articles in multiple languages
* Generation of Atom and RSS feeds
* Import existing content from WordPress, Dotclear, or RSS feeds
* Fast rebuild times due to content caching and selective output writing

Check out [Gemican's documentation](gemini://gemini.hyperlinkyourheart.com/gemicandocs/) for further information.


## Source code

Gemican's source code is [hosted on GitHub](https://github.com/khoulihan/gemican). If you feel like hacking, take a look at [Pelican's internals](gemini://gemini.hyperlinkyourheart.com/gemicandocs/pages/gemican-internals.gmi).


## Why the name "Gemican"?

"Gemican" is an anagram of *camegin*, which means nothing.

Only joking - Gemican is based on the Pelican static site generator, and took its name from that.
